/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されている License.txt に定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene;


/**
 * Paraseleneのバージョン番号。
 */
public class Version {
	private Version(){}
	/**
	 * Paraseleneのバージョン番号を表す文字列。
	 */
	public static final String VERSION = "@@@ver";
	private static final String	TITLE = "Paraselene  Version " + VERSION;

	/**
	 * Paraseleneのアプリタイトル文字列。
	 */
	public static String getTitle() {
		return TITLE;
	}

	/**
	 * Paraseleneの著作権表示。
	 */
	public static String getCopyRight() {
		return "Copyright 2009 @@@auth";
	}
}

